function [I] = F(E,K,x,y,z,normal,lambda)
%
%   Routine to calculate the inverse Fourier transform based on the Fourier
%
%   transform obtained from JCMsuite, a solver for time-harmonic Maxwells 
%
%   equations and other applications using the finite element method
%
%   Disclaimer: Certain commercial materials are identified in order to 
%
%   specify the experimental procedure adequately. 
%
%   Such identification is not intended to imply recommendation or 
%
%   endorsement by the author, nor is it intended to imply that the 
%
%   materials are necessarily the best available for the purpose.
%
%
%   Input:
%
%   - E is the matrix with the field amplitudes for each of the planewaves
%
%     usually the E field, the M field is calculated from it using
%
%       rot E = i omega M, with M=mu H
%
%   - K is the matrix with the components of the propagation vector of the
%
%     different Fourier modes
%
%   - x,y and z are the coordinates in meters of the point you calculate 
%
%     the inverse Fourier transformation for, unit is meters
%
%   - normal is the surface normal to the substrate
%
%   - lambda is the incident wavelength in meters
%
%   Output:
%
%   - I, the intensity as the magnitude of the Poynting vector in the
%
%     normal direction
%
%
%   Author: Mark-Alexander Henn
%
%   Contact: mark.alex.henn@gmail.com
%
[m,~]=size(E);
Efield=[0 0 0];
Hfield=[0 0 0]';
%
%   - define constants: the speed of light in m/s, the vacuum permeability
%
%   - calculate the angular velocity
%
c=299792458; 
mu=4*pi*10^(-7);
omega=2*pi*c/lambda;
%
%   - calculate the H field from the curl of the E field
%
for j=1:m
    Efield=Efield+E(j,1:3)*exp(1i*(K(j,1)*x+K(j,2)*y+K(j,3)*z));
    Hfield(1)=Hfield(1)+(E(j,3)*K(j,2)-E(j,2)*K(j,3))*exp(1i*(K(j,1)*x...
        +K(j,2)*y+K(j,3)*z));
    Hfield(2)=Hfield(2)+(E(j,1)*K(j,3)-E(j,3)*K(j,1))*exp(1i*(K(j,1)*x...
        +K(j,2)*y+K(j,3)*z));
    Hfield(3)=Hfield(3)+(E(j,2)*K(j,1)-E(j,1)*K(j,2))*exp(1i*(K(j,1)*x...
        +K(j,2)*y+K(j,3)*z));
end
Hfield=-Hfield/(mu*omega);
Efield=Efield.';
%
%   - calculate the intensity based on the normal component of the
%
%     Poynting vector S1
%
S1=real(cross(Efield,conj(Hfield)))/2;
S1=normal*S1;
I=abs(S1);

end

