function [ImSP,ImSS] = constructimage(thetas,xmin,xmax,nx,y,z,lambda,CNA,...
    KP,EP,nP,KS,ES,nS,normal)
%
%   Routine to compute an intensity profile based on the fourier transform 
%
%   given by JCMsuite a solver for time-harmonic Maxwells equations and 
%
%   other applications using the finite element method
%
%   Disclaimer: Certain commercial materials are identified in order to 
%
%   specify the experimental procedure adequately. 
%
%   Such identification is not intended to imply recommendation or 
%
%   endorsement by the author, nor is it intended to imply that the 
%
%   materials are necessarily the best available for the purpose.
%
%
%
%   Input:
%
%   - thetas contains the azimuthal angles in degrees of the individual incident 
%
%     planewaves
%
%   - in this setting x is the coordinate along which the intensity profile
%
%     is taken
%
%   - xmin is the lower bound for the x coordinate in meters
%
%   - xmax is the upper bound
%
%   - nx is the number of points along the x axis
%
%   - y and z are the remaining coordinate directions, see schematic
%
%   - lambda is the wavelength in meters
%
%   - CNA is the collection numerical aperture, 0<CNA<=1
%
%   - KP, EP, KS, ES are the k vectors and the E field directions for the
%
%     individual plane waves for the respective polarizations, if KPi and
%     
%     EPi are the respective matrices for the i-th plane wave, then
%
%     KP=[KP1;KP2;KP3....] and EP=[EP1;EP2;EP3....]
%
%     same for KS and ES
%
%   - nP, nS are vectors that consist of the numbers of Fourier components
%
%     for the individual incident plane waves, i.e. the length of the KPis/KSis 
%
%     and EPis/ESis, this means that if there are 4 incident plane waves, 
%
%     nP and nS have 4 entries
%
%   - normal is the normal vector, i.e. the direction normal to the
%
%     substrate, this is also the direction that determines the focus
%     
%     height
%
%   Output:
%
%   - ImSP is the image for polarization in the plane of propagation 
%
%     ImSS is the image for polarization perpendicular to the plane of
%
%     propagation
%
%   - The intensity is based on the normal component of the Poynting vector
%
%
%   To generate one of the images in the ImageNW12INA0.1NL10NF11193nmFIN.mat file
%
%   choose a focusheight y between -0.5 and +0.5 micro meters and type  
%
%   [ImSP,ImSS] = constructimage(thetaS,-1.5*10^(-6),1.5*10^(-6),120,y,0,193*10^(-9),0.95,KDWP,EDWP,NWP,KDWS,EDWS,NWS,[0 1 0])
%
%
%   Author: Mark-Alexander Henn
%
%   Contact: mark.alex.henn@gmail.com
%
nplanewaves=length(thetas);

if nargin>15
    perp=cross([1 0 0]',normal');
    P=inv([[1 0 0]', normal', perp]);
    KP=KP*P;
    EP=EP*P;
    KS=KS*P;
    ES=ES*P;
else
    
end

[~,mi]=min(nP);
[~,ma]=max(nP);
if mi==1 && ma==nplanewaves

else
    for i=1:nplanewaves
        nPt(i)=sum(nP(1:i));
        nSt(i)=sum(nS(1:i));
    end
    nP=nPt;
    nS=nSt;
end

nP=[0 nP];
nS=[0 nS];

x=linspace(xmin,xmax,nx);
IEP=zeros(nx,nplanewaves);
ISP=IEP;
ISS=IEP;
ImEP=zeros(nx,1);
ImSP=ImEP;
ImSS=ImEP;

for i=1:nplanewaves
    Ktmp=KP(nP(i)+1:nP(i+1),:);
    Etmp=EP(nP(i)+1:nP(i+1),:);
    size(Ktmp);
    if CNA(1)<1
        [Ktmp,Etmp]=CNAaccount(Ktmp,Etmp,CNA);
    else
        
    end
    size(Ktmp);
    for j=1:nx;% replace with parfor if you have parallelization
        [IStmp] = F(Etmp,Ktmp,x(j),y,z,normal,lambda);
        ISP(j,i)=IStmp;
    end
    %%%%
    %
    %   - calculate image based on reflected field only
    %
    %   - used to normalize the image
    %
    [RT] = F(Etmp(end,:),Ktmp(end,:),x(nx),y,z,normal,lambda);
    
    REFPS(i)=RT;
    Ktmp=KS(nS(i)+1:nS(i+1),:);
    Etmp=ES(nS(i)+1:nS(i+1),:);
    
    if CNA<1
        [Ktmp,Etmp]=CNAaccount(Ktmp,Etmp,CNA);
    else
        
    end
    
    for j=1:nx;% replace with parfor if you have parallelization
        [IStmp] = F(Etmp,Ktmp,x(j),y,z,normal,lambda);
        ISS(j,i)=IStmp;
    end
    %%%%
    %
    %   - calculate image based on reflected only
    %
    %   - used to normalize the image
    %
    [RT] = F(Etmp(end,:),Ktmp(end,:),x(nx),y,z,normal,lambda);
    
    REFSS(i)=RT;
end

for i=1:nplanewaves
    w=1/cosd(thetas(i));
    ISP(:,i)=ISP(:,i)*w;
    ISS(:,i)=ISS(:,i)*w;
end

for i=1:nx
    ImSP(i)=sum(ISP(i,:));
    ImSS(i)=sum(ISS(i,:));
end


ImSP=ImSP/sum(REFPS);
ImSS=ImSS/sum(REFSS); 
end

%%%%%
%
%   - local functions
%
function[KCNA,ECNA]=CNAaccount(K,E,CNA)
%
%   - function accounts for collection numerical aperture
%
if length(CNA)>1;
    CNAmin=CNA(2);
    CNAmax=CNA(1);
    thetamin=asind(CNAmin);
    thetamax=asind(CNAmax);
else
    CNAmax=CNA;
    thetamax=asind(CNAmax);
    thetamin=0;
end

s=size(K);
s=s(1);
Ktmp=K;
Etmp=E;

ang=zeros(s);
for i=1:s
    Kt=sqrt(K(i,1)^2+K(i,3)^2);
    ang(i)=atand(Kt/K(i,2));
end


for i=1:s
    j=s+1-i;
     if abs(ang(j))>thetamax || abs(ang(j))<thetamin
        Ktmp(j,:)=[];
        Etmp(j,:)=[];
    else
            
    end
end

ECNA=Etmp;

KCNA=Ktmp;

end

