function [] = creategeo2Dfin(geo0,NL,UoL)
%
%   Routine to generate an 2D input geometry file called "layout.jcm" 
%
%   for JCMsuite a solver for time-harmonic Maxwells equations and 
%
%   other applications using the finite element method, basic structure is 
%
%   a fin structure buried in an overlayer, e.g. silicon fins in silicon 
%
%   oxide
%
%   Disclaimer: Certain commercial materials are identified in order to 
%
%   specify the experimental procedure adequately. 
%
%   Such identification is not intended to imply recommendation or 
%
%   endorsement by the author, nor is it intended to imply that the 
%
%   materials are necessarily the best available for the purpose.
%
%
%   Input:
%
%   - geo0 is a vector containing the width, the height above the overlayer, 
%
%     the pitch, delta top, delta bottom, the height of the overlayer and  
%
%     radius of the corner rounding for a single fin in units of length, 
%
%     see Parameter.png for more information
%
%   - NL is the number of fins, must be even
%
%   - UoL is the unit of length in meters
%
%
%   Output:
%
%   - 2D input geometry file called "layout.jcm"
%
%   - file must be copied to the JCM project's directory in order to
%
%     perform the simulation
%
%
%   To generate the geometry that has been used to obtain the supplied
%   
%   results type: creategeo2Dfin([20 35 60],10,10^(-9))
%
%
%   Author: Mark-Alexander Henn
%
%   Contact: mark.alex.henn@gmail.com
%
width=geo0(1);
height=geo0(2);
pitch=geo0(3);
%%%%%%
%
%
deltop=geo0(4);
delbot=geo0(5);
heightOx=geo0(6);
radius=geo0(7);

if pitch<=width+2*delbot || width-2*deltop<=0 || width-2*deltop<=2*radius || min(geo0)<0 
    disp('Please check geometry parameters.')
    return
    
else
    
end

if mod(NL,2)>0
    disp('Number of lines must be even.')
    return
else
    
end

heightbox=height+2*radius;
LX=NL/2*pitch;
%
%   - calculate the coordinates of the points defining the profiles
%
for i=1:NL/2
    LEH(i)=(pitch-width)/2+(i-1)*pitch;
    REH(i)=LEH(i)+width;
    LEH(i+NL/2)=-LEH(i);
    REH(i+NL/2)=-REH(i);
    
    LEB(i)=LEH(i)-delbot;
    REB(i)=REH(i)+delbot;
    LEB(i+NL/2)=-LEB(i);
    REB(i+NL/2)=-REB(i);
    
    LET(i)=LEH(i)+deltop;
    RET(i)=REH(i)-deltop;
    LET(i+NL/2)=-LET(i);
    RET(i+NL/2)=-RET(i);
    
    RAD=radius;
    CXL(i)=LET(i)+RAD;
    CXR(i)=RET(i)-RAD;
    CXL(i+NL/2)=-CXL(i);
    CXR(i+NL/2)=-CXR(i);
end
%
%   - write file to match JCMsuite format
%
fileID=fopen('layout.jcm','w');

fprintf(fileID,['Layout {\n UnitOfLength=%d\n Polygon {\n Name=' ...
    '"ComputationalDomain"\n DomainId=1\n Points='...
    '[-%d -10 %d -10 %d %d -%d %d]\n Priority=-1\n'],...
    UoL,LX, LX, LX,heightbox, LX, heightbox);
for i=1:4
    fprintf(fileID,'BoundarySegment {\n');
    fprintf(fileID,'Number=%d\n',i);
    fprintf(fileID,'BoundaryClass=TransparentBoundary\n');
    fprintf(fileID,'}\n');
end
fprintf(fileID,'}\n');

fprintf(fileID,'Polygon{\n');
fprintf(fileID,'Name="Substrate"\n');
fprintf(fileID,'MaterialId = 2\n'); 
fprintf(fileID,'Priority=1\n');
fprintf(fileID,'AreaConstraint = 100\n');
fprintf(fileID,'Points=[-%d -10 %d -10 %d %d -%d %d]\n',LX,LX,LX,0,LX,0);
fprintf(fileID,'}\n');


for i=1:NL/2
    fprintf(fileID,'Polygon{\n');
    fprintf(fileID,'Name="MyLine%d"\n',i);
    fprintf(fileID,'Priority=1\n');
    fprintf(fileID,'MaterialId = 3\n');
    fprintf(fileID,'AreaConstraint = 100\n');
    fprintf(fileID,'Points=[');
    fprintf(fileID,'%d 0 %d 0 %d %d %d %d %d %d %d %d',LEB(i), REB(i),...
        REH(i), heightOx, RET(i), height+heightOx, LET(i), height,...
        LEH(i), heightOx+heightOx);
    fprintf(fileID,']\n');
    fprintf(fileID,'}\n');
    
    fprintf(fileID,'Circle {\n');
    fprintf(fileID,'Name="LeftCircle%d"\n',i);
    fprintf(fileID,'Priority=1\n');
    fprintf(fileID,'MaterialId = 3\n');
    fprintf(fileID,'GlobalPositionX = %d\n',CXL(i));
    fprintf(fileID,'GlobalPositionY = %d\n',height);
    fprintf(fileID,'Radius = %d\n',RAD);
    fprintf(fileID,'AreaConstraint = 0.2\n');
    fprintf(fileID,'}\n');
    fprintf(fileID,'Circle {\n');
    
    fprintf(fileID,'Name="RightCircle%d"\n',i);
    fprintf(fileID,'Priority=1\n');
    fprintf(fileID,'MaterialId = 3\n');
    fprintf(fileID,'GlobalPositionX = %d\n',CXR(i));
    fprintf(fileID,'GlobalPositionY = %d\n',height);
    fprintf(fileID,'Radius = %d\n',RAD);
    fprintf(fileID,'AreaConstraint = 0.2\n');
    fprintf(fileID,'}\n');
    
    fprintf(fileID,'Polygon{\n');
    fprintf(fileID,'Name="MyTopLine%d"\n',i);
    fprintf(fileID,'Priority=1\n');
    fprintf(fileID,'MaterialId = 3\n');
    fprintf(fileID,'AreaConstraint = 100\n');
    fprintf(fileID,'Points=[');
    fprintf(fileID,'%d %d %d %d %d %d %d %d',CXL(i), height+heightOx,...
        CXR(i), height+heightOx, CXR(i), height+heightOx+RAD, CXL(i),...
        height+heightOx+RAD);
    fprintf(fileID,']\n');
    fprintf(fileID,'}\n');
    
    
    
end

for i=NL/2+1:NL
    fprintf(fileID,'Polygon{\n');
    fprintf(fileID,'Name="MyLine%d"\n',i);
    fprintf(fileID,'Priority=1\n');
    fprintf(fileID,'MaterialId = 3\n');
    fprintf(fileID,'AreaConstraint = 100\n');
    fprintf(fileID,'Points=[');
    fprintf(fileID,'%d 0 %d %d %d %d %d %d %d %d %d 0 ',LEB(i), LEH(i),...
        heightOx, LET(i), height+heightOx, RET(i), height+heightOx,...
        REH(i), heightOx, REB(i));
    fprintf(fileID,']\n');
    fprintf(fileID,'}\n');
    
    fprintf(fileID,'Circle {\n');
    fprintf(fileID,'Name="LeftCircle%d"\n',i);
    fprintf(fileID,'Priority=1\n');
    fprintf(fileID,'MaterialId = 3\n');
    fprintf(fileID,'GlobalPositionX = %d\n',CXL(i));
    fprintf(fileID,'GlobalPositionY = %d\n',height);
    fprintf(fileID,'Radius = %d\n',RAD);
    fprintf(fileID,'AreaConstraint = 0.2\n');
    fprintf(fileID,'}\n');
    fprintf(fileID,'Circle {\n');
    
    fprintf(fileID,'Name="RightCircle%d"\n',i);
    fprintf(fileID,'Priority=1\n');
    fprintf(fileID,'MaterialId = 3\n');
    fprintf(fileID,'GlobalPositionX = %d\n',CXR(i));
    fprintf(fileID,'GlobalPositionY = %d\n',height);
    fprintf(fileID,'Radius = %d\n',RAD);
    fprintf(fileID,'AreaConstraint = 0.2\n');
    fprintf(fileID,'}\n');
    
     fprintf(fileID,'Polygon{\n');
     fprintf(fileID,'Name="MyTopLine%d"\n',i);
     fprintf(fileID,'Priority=1\n');
     fprintf(fileID,'MaterialId = 3\n');
     fprintf(fileID,'AreaConstraint = 100\n');
     fprintf(fileID,'Points=[');
     fprintf(fileID,'%d %d %d %d %d %d %d %d',CXR(i), height+heightOx,...
         CXL(i), height+heightOx, CXL(i), height+heightOx+RAD, CXR(i),...
         height+heightOx+RAD);
     fprintf(fileID,']\n');
     fprintf(fileID,'}\n');
    
end
fprintf(fileID,'Polygon{\n');
    fprintf(fileID,'Name="Oxide"\n');
    fprintf(fileID,'Priority=0\n');
    fprintf(fileID,'MaterialId = 4\n');
    fprintf(fileID,'AreaConstraint = 100\n');
    fprintf(fileID,'Points=[');
    fprintf(fileID,'%d 0 %d %d %d %d %d 0 ',LX,LX,heightOx,-LX,...
        heightOx,-LX);
    fprintf(fileID,']\n');
    fprintf(fileID,'}\n');


fprintf(fileID,'}\n');
fclose(fileID);

end
