function [] = creategeo3Drec(geo0,LY,NL,UoL,periodic)
%
%   Routine to generate an 3D input geometry file called "layout.jcm" for 
%
%   JCMsuite a solver for time-harmonic Maxwells equations and 
%
%   other applications using the finite element method, basic structure is 
%
%   rectangular
%
%   Disclaimer: Certain commercial materials are identified in order to 
%
%   specify the experimental procedure adequately. 
%
%   Such identification is not intended to imply recommendation or 
%
%   endorsement by the author, nor is it intended to imply that the 
%
%   materials are necessarily the best available for the purpose.
%
%
%   Input:
%
%   - geo0 is a vector containing the width, the height and the pitch for a 
%
%     single line in units of length, see Parameter.png for more information
%
%   - LY is the length of the structure in units of length
%
%   - NL is the number of lines, must be even
%
%   - UoL is the unit of length in meters
%
%   - periodic determines whether the structure is assumed to be infinitely
%
%     long (periodic=1) or not (periodic=0)
%
%
%   Output:
%
%   -3D input geometry file called "layout.jcm"
%
%   - file must be copied to the JCM project's directory in order to
%   
%     perform the simulation
%
%
%   To generate the geometry that has been used to obtain the supplied
%   
%   results type: creategeo3Drec([25 40 60 8 10 70 2],1500,10,10^(-9),1) 
%
%   and creategeo3Drec([25 40 60 8 10 70 2],1500,10,10^(-9),0)
%
%
%   Author: Mark-Alexander Henn
%
%   Contact: mark.alex.henn@gmail.com
%
width=geo0(1);
height=geo0(2);
pitch=geo0(3);

if mod(NL,2)>0
    disp('Number of lines must be even.')
    return
else
    
end

if width>=pitch || min(geo0)<=0
    disp('Please check geometry parameters, they need to be positive. Pitch needs to be larger than width.')
    return
else
    LY=LY/2;
    if periodic==1;
        LL=LY;
    else
        LL=LY;
        LY=LY+10;
    end

    LX=NL/2*pitch;

    dely=2*LL;

    for i=1:NL/2
        LE(i)=(pitch-width)/2+(i-1)*pitch;
        RE(i)=LE(i)+width;
        LE(i+NL/2)=-LE(i);
        RE(i+NL/2)=-RE(i);
    end

    fileID=fopen('layout.jcm','w');

    fprintf(fileID,['Layout {\n UnitOfLength=%d\n Polygon {\n Name='...
        '"ComputationalDomain"\n DomainId=1\n'...
        'Points=[-%d -%d %d -%d %d %d -%d %d]\n Priority=-1\n'],...
        UoL,LX,LY,LX,LY,LX,LY,LX,LY);
    for i=1:4
        fprintf(fileID,'BoundarySegment {\n');
        fprintf(fileID,'Number=%d\n',i);
        if i==1||i==3
            if periodic==1;
                fprintf(fileID,'BoundaryClass=PeriodicBoundary\n');
            else
                fprintf(fileID,'BoundaryClass=TransparentBoundary\n');
            end
        else
        fprintf(fileID,'BoundaryClass=TransparentBoundary\n');
        end
        fprintf(fileID,'}\n');
    end
    fprintf(fileID,'}\n');


    for i=1:NL/2
        fprintf(fileID,'Polygon{\n');
        fprintf(fileID,'Name="MyLine%d"\n',i);
        fprintf(fileID,'DomainId=%d\n',i+1);
        fprintf(fileID,'Points=[\n');
        for j=1:2
            xcoord=RE(i);
            ycoord=-LL+(j-1)*dely;
            fprintf(fileID,'%d %d ',xcoord,ycoord);
        end
        for j=1:2
            xcoord=LE(i);
            ycoord=LL-(j-1)*dely;
            fprintf(fileID,'%d %d ',xcoord,ycoord);
        end
        fprintf(fileID,']\n');
        fprintf(fileID,'Priority=1\n');
        fprintf(fileID,'}\n');
    end

    for i=NL/2+1:NL
        fprintf(fileID,'Polygon{\n');
        fprintf(fileID,'Name="MyLine%d"\n',i);
        fprintf(fileID,'DomainId=%d\n',i+1);
        fprintf(fileID,'Points=[\n');
        for j=1:2
            xcoord=LE(i);
            ycoord=-LL+(j-1)*dely;
            fprintf(fileID,'%d %d ',xcoord,ycoord);
        end
        for j=1:2
            xcoord=RE(i);
            ycoord=LL-(j-1)*dely;
            fprintf(fileID,'%d %d ',xcoord,ycoord);
        end
        fprintf(fileID,']\n');
        fprintf(fileID,'Priority=1\n');
        fprintf(fileID,'}\n');
    end

    fprintf(fileID,'HeightProfile {\n InfiniteLayer {\n DomainIdMapping=[');

    for i=1:NL;
        fprintf(fileID,'%d 2, ',i);
    end
    fprintf(fileID,'%d 2 ',NL+1);
    fprintf(fileID,']\n }\n');

    fprintf(fileID,'Layer{\n');
    fprintf(fileID,'Thickness=%d\n',height);
    fprintf(fileID,'DomainIdMapping=[');
    fprintf(fileID,'%d 1 ',1);
    for i=2:NL+1;
        fprintf(fileID,',%d 3 ',i);
    end
    fprintf(fileID,']\n }\n');

    fprintf(fileID,'Layer{\n');
    fprintf(fileID,'Thickness=%d\n',5);
    fprintf(fileID,'DomainIdMapping=[');
    for i=1:NL;
        fprintf(fileID,'%d 1, ',i);
    end
    fprintf(fileID,'%d 1 ',NL+1);
    fprintf(fileID,']\n }\n');

    fprintf(fileID,'InfiniteLayer {\n DomainIdMapping=[');
    for i=1:NL;
        fprintf(fileID,'%d 1, ',i);
    end
    fprintf(fileID,'%d 1 ',NL+1);
    fprintf(fileID,']\n }\n }\n }\n');

    fclose(fileID);
end
end
