function [kvec,evec,thetaall,phiall] = kvectors(INA,lambda,Ny,pol)
%
%   Routine to calculate k vectors and directions of the E field for a
%
%   set of plane waves corresponding to a finite illumination numerical
%
%   aperture and polarization state, the coordinates correspond to the
%
%   2D coordinate system in coord.png, i.e. the order needs to be changed
%
%   accordingly if used for 3D calculations, if k is the i-th row of kvec and
%
%   E the i-th row of evec the plane wave is defined by
%
%       U(x)=E*exp(i(k,x))
%
%
%   Input:
%
%   - INA the illumination numerical aperture, INA=0 leads to single plane 
%
%     wave at normal incidence
%
%   - lambda the incident wavelength in meters
%
%   - Ny determines the number of patches in the back focal plane #p, 
%
%     roughly Ny^2=#p
%
%   - pol determines the polarization, 0 for p-polarization, 1 for s-polarization,
%   
%     and 0 for x and 1 for y polarization for the single plane wave
%
%   Output:
%
%   - matrices kvec and evec whose row entries are the k vectors
%
%     (kvec) and directions of the E field (evec) for an individual plane
%     
%     wave
%
%   - thetall, the azimuthal angles in degrees
%
%   - phiall, the radial angles in degrees
%
%
%
%   To generate the vectors that have been used to obtain the supplied
%   
%   results type: kvectors(0.1,193*10^(-9),4,0) and kvectors(0.1,193*10^(-9),4,1)
%
%
%   Author: Mark-Alexander Henn
%
%   Contact: mark.alex.henn@gmail.com
%
n=1;    % refractive index of material above scatterer;
kvec=[];
evec=[];
r=2*pi/lambda;

INAp=INA/n;
k=1;

if INA==0
   kvec=[0 -r 0];
   thetaall=0;
   phiall=0;
   if pol==0
      evec=[1 0 0]; 
   else
      evec=[0 0 1];
   end
else

    Dypp=2*INAp;
    dypp=Dypp/Ny;
    Nx=Ny;
    doxpp=2*INAp/Nx;

    thetaall=[];
    phiall=[];

    for i=1:Ny;
        ypp(i)=-INAp+(i-1/2)*dypp;
        ypp(i)=-ypp(i);

        Xi=2*sqrt(INAp^2-ypp(i)^2);
        Nxppi=ceil(Xi/doxpp);
        dixpp=Xi/Nxppi;
        for j=1:Nxppi
           xpp(j)=(j-0.5*Nxppi-0.5)*dixpp;
           [kx,ky,kz,theta,phi]=anglexy(xpp(j),ypp(i),k,r);

            kt=[kx,0,kz];
            kin=[kx,ky,kz];
            nkt=norm(kt);
            nk=norm(kin);

            if nkt==0;
                es=[1 0 0];
                ep=[0 0 1];

                if pol==0;
                   evec=[evec;es]; 
                else
                   evec=[evec;ep];
                end
                kvec=[kvec;kin];
            else
                es=[kz 0 -kx]/nkt;
                ep=[-kx*ky nkt*nkt -ky*kz]/(nk*nkt);
                if pol==0; 
                   E0xs=sind(phi);
                   E0xp=-cosd(phi);
                   evec=[evec;(E0xs*es+E0xp*ep)];
                else
                   E0ys=-cosd(phi);
                   E0yp=-sind(phi);
                   evec=[evec;(E0ys*es+E0yp*ep)];
                end
                kvec=[kvec;kin];
            end
            phiall=[phiall;phi];
            thetaall=[thetaall;theta];

        end
    end

    nk=length(kvec);
    length(evec)
    for i=1:nk
        indx=nk+1-i;
        if norm(evec(indx,:))==0;
            evec(indx,:)=[];
            kvec(indx,:)=[];
        else
        end
    end
end
end
%%%%%
%
%   - local functions
%
function[kx,ky,kz,theta,phi]=anglexy(x,y,k,r)
%
%   - determine the k vector and the azimuthal and polar angles
%
    if x==0;
        if y>0
            phi=90;
            theta=asind(y/(k*sind(phi)));
        elseif y<0
            phi=270;
            theta=asind(y/(k*sind(phi)));
        else
            phi=0;
            theta=0;
        end
    else
        phi=atand(y/x);
        theta=asind(x/(k*cosd(phi)));
    end
      
    kx=r*sind(theta)*cosd(-phi);
    ky=-r*cosd(theta);
    kz=r*sind(theta)*sind(-phi);
        
end